@@ -2,7 +2,7 @@ context("Checking escape")
 
 test_that("escape produces a class of `escape`",{
 	
-    expect_identical(escape("X"), structure("X", class = c("escape", "character")))
+    expect_equivalent(escape("X"), structure("X", class = c("escape", "character")))
 
 })
 
@@ -11,15 +11,14 @@ test_that("escape does not parse these strings",{
 	
     x <- "...character vector.  Default, \\code{@rm_caps} uses..."
 
-    expect_identical(rm_default(x, pattern = "@rm_caps"),
+    expect_equivalent(rm_default(x, pattern = "@rm_caps"),
     	"...character vector. Default, \\code{@rm_caps} uses...")
-    expect_identical(rm_default(x, pattern = escape("@rm_caps")),
+    expect_equivalent(rm_default(x, pattern = escape("@rm_caps")),
     	"...character vector. Default, \\code{} uses...")
 	
-	expect_identical(pastex(escape("@rm_caps")), "@rm_caps")
+	expect_equivalent(pastex(escape("@rm_caps")), "@rm_caps")
 
 })
 
 
 
-
